<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Valore non valido fornito per %s",
"Saved" => "Salvato",
"test email settings" => "prova impostazioni email",
"If you received this email, the settings seem to be correct." => "Se hai ricevuto questa email, le impostazioni dovrebbero essere corrette.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Si è verificato un problema durante l'invio dell'email. Controlla le tue impostazioni.",
"Email sent" => "Email inviata",
"You need to set your user email before being able to send test emails." => "Devi impostare l'indirizzo del tuo utente prima di poter provare l'invio delle email.",
"Send mode" => "Modalità di invio",
"Encryption" => "Cifratura",
"Authentication method" => "Metodo di autenticazione",
"Unable to load list from App Store" => "Impossibile caricare l'elenco dall'App Store",
"Authentication error" => "Errore di autenticazione",
"Your full name has been changed." => "Il tuo nome completo è stato cambiato.",
"Unable to change full name" => "Impossibile cambiare il nome completo",
"Group already exists" => "Il gruppo esiste già",
"Unable to add group" => "Impossibile aggiungere il gruppo",
"Files decrypted successfully" => "File decifrato correttamente",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Impossibile decifrare i tuoi file, controlla il file owncloud.log o chiedi al tuo amministratore",
"Couldn't decrypt your files, check your password and try again" => "Impossibile decifrare i tuoi file, controlla la password e prova ancora",
"Encryption keys deleted permanently" => "Chiavi di cifratura eliminate definitivamente",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Impossibile eliminare definitivamente le chiavi di cifratura, controlla il file owncloud.log o chiedi al tuo amministratore",
"Couldn't remove app." => "Impossibile rimuovere l'applicazione.",
"Email saved" => "Email salvata",
"Invalid email" => "Email non valida",
"Unable to delete group" => "Impossibile eliminare il gruppo",
"Unable to delete user" => "Impossibile eliminare l'utente",
"Backups restored successfully" => "Copie di sicurezza ripristinate correttamente",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Impossibile ripristinare le chiavi di cifratura, controlla il file owncloud.log o chiedi al tuo amministratore",
"Language changed" => "Lingua modificata",
"Invalid request" => "Richiesta non valida",
"Admins can't remove themself from the admin group" => "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
"Unable to add user to group %s" => "Impossibile aggiungere l'utente al gruppo %s",
"Unable to remove user from group %s" => "Impossibile rimuovere l'utente dal gruppo %s",
"Couldn't update app." => "Impossibile aggiornate l'applicazione.",
"Wrong password" => "Password errata",
"No user supplied" => "Non è stato fornito alcun utente",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Fornisci una password amministrativa di ripristino altrimenti tutti i dati degli utenti saranno persi.",
"Wrong admin recovery password. Please check the password and try again." => "Password amministrativa di ripristino errata. Controlla la password e prova ancora.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Il motore non supporta la modifica della password, ma la chiave di cifratura dell'utente è stata aggiornata correttamente.",
"Unable to change password" => "Impossibile cambiare la password",
"Sending..." => "Invio in corso...",
"User Documentation" => "Documentazione utente",
"Admin Documentation" => "Documentazione di amministrazione",
"Update to {appversion}" => "Aggiorna a {appversion}",
"Uninstall App" => "Disinstalla applicazione",
"Disable" => "Disabilita",
"Enable" => "Abilita",
"Please wait...." => "Attendere...",
"Error while disabling app" => "Errore durante la disattivazione",
"Error while enabling app" => "Errore durante l'attivazione",
"Updating...." => "Aggiornamento in corso...",
"Error while updating app" => "Errore durante l'aggiornamento",
"Error" => "Errore",
"Update" => "Aggiorna",
"Updated" => "Aggiornato",
"Uninstalling ...." => "Disinstallazione...",
"Error while uninstalling app" => "Errore durante la disinstallazione dell'applicazione",
"Uninstall" => "Disinstalla",
"Select a profile picture" => "Seleziona un'immagine del profilo",
"Very weak password" => "Password molto debole",
"Weak password" => "Password debole",
"So-so password" => "Password così-così",
"Good password" => "Password buona",
"Strong password" => "Password forte",
"Decrypting files... Please wait, this can take some time." => "Decifratura dei file in corso... Attendi, potrebbe richiedere del tempo.",
"Delete encryption keys permanently." => "Elimina definitivamente le chiavi di cifratura.",
"Restore encryption keys." => "Ripristina le chiavi di cifratura.",
"Unable to delete {objName}" => "Impossibile eliminare {objName}",
"Error creating group" => "Errore durante la creazione del gruppo",
"A valid group name must be provided" => "Deve essere fornito un nome valido per il gruppo",
"deleted {groupName}" => "{groupName} eliminato",
"undo" => "annulla",
"Groups" => "Gruppi",
"Group Admin" => "Gruppi amministrati",
"Delete" => "Elimina",
"never" => "mai",
"deleted {userName}" => "{userName} eliminato",
"add group" => "aggiungi gruppo",
"A valid username must be provided" => "Deve essere fornito un nome utente valido",
"Error creating user" => "Errore durante la creazione dell'utente",
"A valid password must be provided" => "Deve essere fornita una password valida",
"Warning: Home directory for user \"{user}\" already exists" => "Avviso: la cartella home dell'utente \"{user}\" esiste già",
"__language_name__" => "Italiano",
"Everything (fatal issues, errors, warnings, info, debug)" => "Tutto (problemi gravi, errori, avvisi, informazioni, debug)",
"Info, warnings, errors and fatal issues" => "Informazioni, avvisi, errori e problemi gravi",
"Warnings, errors and fatal issues" => "Avvisi, errori e problemi gravi",
"Errors and fatal issues" => "Errori e problemi gravi",
"Fatal issues only" => "Solo problemi gravi",
"None" => "Nessuno",
"Login" => "Accesso",
"Plain" => "Semplice",
"NT LAN Manager" => "Gestore NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Avviso di sicurezza",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Sei connesso a %s tramite HTTP. Ti suggeriamo vivamente di configurare il tuo server per richiedere l'utilizzo del protocollo HTTPS al posto di HTTP.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet.\nIl file .htaccess non funziona. Ti consigliamo vivamente di configurare il server web in modo che la cartella dei dati non sia più accessibile o spostare la cartella fuori dalla radice del server web.",
"Setup Warning" => "Avviso di configurazione",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Il tuo server web non è configurato correttamente per consentire la sincronizzazione dei file poiché l'interfaccia WebDAV sembra essere danneggiata.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Leggi attentamente le <a href='%s'>guide d'installazione</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
"Database Performance Info" => "Informazioni prestazioni del database",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "SQLite è utilizzato come database. Per installazioni grandi, consigliamo di cambiarlo. Per migrare a un altro database, utilizzare lo strumento da riga di comando: 'occ db:convert-type'",
"Module 'fileinfo' missing" => "Modulo 'fileinfo' mancante",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
"Your PHP version is outdated" => "La tua versione di PHP è obsoleta",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "La tua versione di PHP è obsoleta. Ti consigliamo vivamente di aggiornare alla versione 5.3.8 o successiva poiché sono noti problemi con le vecchie versioni. L'installazione attuale potrebbe non funzionare correttamente.",
"Locale not working" => "Locale non funzionante",
"System locale can not be set to a one which supports UTF-8." => "La localizzazione di sistema non può essere impostata a una che supporta UTF-8.",
"This means that there might be problems with certain characters in file names." => "Ciò significa che potrebbero esserci problemi con alcuni caratteri nei nomi dei file.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Consigliamo vivamente di installare i pacchetti richiesti sul tuo sistema per supportare una delle\nlocalizzazioni seguenti: %s.",
"Internet connection not working" => "Connessione Internet non funzionante",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Questo server ownCloud non ha una connessione a Internet funzionante. Ciò significa che alcune delle funzionalità come il montaggio di archivi esterni, le notifiche degli aggiornamenti o l'installazione di applicazioni di terze parti non funzioneranno. L'accesso remoto ai file e l'invio di email di notifica potrebbero non funzionare. Ti suggeriamo di abilitare la connessione a Internet del server se desideri disporre di tutte le funzionalità.",
"Cron" => "Cron",
"Last cron was executed at %s." => "L'ultimo cron è stato eseguito alle %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "L'ultimo cron è stato eseguito alle %s. È più di un'ora fa, potrebbe esserci qualche problema.",
"Cron was not executed yet!" => "Cron non è stato ancora eseguito!",
"Execute one task with each page loaded" => "Esegui un'operazione con ogni pagina caricata",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php è registrato su un servizio webcron per invocare cron.php ogni 15 minuti su http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Usa il servizio cron di sistema per invocare il file cron.php ogni 15 minuti.",
"Sharing" => "Condivisione",
"Allow apps to use the Share API" => "Consenti alle applicazioni di utilizzare le API di condivisione",
"Allow users to share via link" => "Consenti agli utenti di condivere tramite collegamento",
"Enforce password protection" => "Imponi la protezione con password",
"Allow public uploads" => "Consenti caricamenti pubblici",
"Set default expiration date" => "Imposta data di scadenza predefinita",
"Expire after " => "Scadenza dopo",
"days" => "giorni",
"Enforce expiration date" => "Forza la data di scadenza",
"Allow resharing" => "Consenti la ri-condivisione",
"Restrict users to only share with users in their groups" => "Limita gli utenti a condividere solo con gli utenti nei loro gruppi",
"Allow users to send mail notification for shared files" => "Consenti agli utenti di inviare email di notifica per i file condivisi",
"Exclude groups from sharing" => "Escludi gruppi dalla condivisione",
"These groups will still be able to receive shares, but not to initiate them." => "Questi gruppi saranno in grado di ricevere condivisioni, ma non iniziarle.",
"Security" => "Protezione",
"Enforce HTTPS" => "Forza HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Forza i client a connettersi a %s tramite una connessione cifrata.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Connettiti al tuo %s tramite HTTPS per abilitare o disabilitare l'applicazione di SSL.",
"Email Server" => "Server di posta",
"This is used for sending out notifications." => "Viene utilizzato per inviare le notifiche.",
"From address" => "Indirizzo mittente",
"mail" => "posta",
"Authentication required" => "Autenticazione richiesta",
"Server address" => "Indirizzo del server",
"Port" => "Porta",
"Credentials" => "Credenziali",
"SMTP Username" => "Nome utente SMTP",
"SMTP Password" => "Password SMTP",
"Test email settings" => "Prova impostazioni email",
"Send email" => "Invia email",
"Log" => "Log",
"Log level" => "Livello di log",
"More" => "Altro",
"Less" => "Meno",
"Version" => "Versione",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Sviluppato dalla <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunità di ownCloud</a>, il <a href=\"https://github.com/owncloud\" target=\"_blank\">codice sorgente</a> è rilasciato nei termini della licenza <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Aggiungi la tua applicazione",
"More Apps" => "Altre applicazioni",
"Select an App" => "Seleziona un'applicazione",
"Documentation:" => "Documentazione:",
"See application page at apps.owncloud.com" => "Vedere la pagina dell'applicazione su apps.owncloud.com",
"See application website" => "Visita il sito web dell'applicazione",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licenziato da <span class=\"author\"></span>",
"Enable only for specific groups" => "Abilita solo per gruppi specifici",
"All" => "Tutti",
"Administrator Documentation" => "Documentazione amministratore",
"Online Documentation" => "Documentazione in linea",
"Forum" => "Forum",
"Bugtracker" => "Sistema di tracciamento bug",
"Commercial Support" => "Supporto commerciale",
"Get the apps to sync your files" => "Scarica le applicazioni per sincronizzare i tuoi file",
"Show First Run Wizard again" => "Mostra nuovamente la procedura di primo avvio",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Hai utilizzato <strong>%s</strong> dei <strong>%s</strong> disponibili",
"Password" => "Password",
"Your password was changed" => "La tua password è cambiata",
"Unable to change your password" => "Modifica password non riuscita",
"Current password" => "Password attuale",
"New password" => "Nuova password",
"Change password" => "Modifica password",
"Full Name" => "Nome completo",
"Email" => "Posta elettronica",
"Your email address" => "Il tuo indirizzo email",
"Fill in an email address to enable password recovery and receive notifications" => "Inserisci il tuo indirizzo di posta per abilitare il recupero della password e ricevere notifiche",
"Profile picture" => "Immagine del profilo",
"Upload new" => "Carica nuova",
"Select new from Files" => "Seleziona nuova da file",
"Remove image" => "Rimuovi immagine",
"Either png or jpg. Ideally square but you will be able to crop it." => "Sia png che jpg. Preferibilmente quadrata, ma potrai ritagliarla.",
"Your avatar is provided by your original account." => "Il tuo avatar è ottenuto dal tuo account originale.",
"Cancel" => "Annulla",
"Choose as profile image" => "Scegli come immagine del profilo",
"Language" => "Lingua",
"Help translate" => "Migliora la traduzione",
"The encryption app is no longer enabled, please decrypt all your files" => "L'applicazione di cifratura non è più abilitata, decifra tutti i tuoi file",
"Log-in password" => "Password di accesso",
"Decrypt all Files" => "Decifra tutti i file",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Le tue chiavi di cifratura sono state spostate in una posizione sicura. Se qualcosa non dovesse funzionare, potrai ripristinare le chiavi. Eliminale definitivamente solo se sei sicuro che tutti i file siano stati decifrati.",
"Restore Encryption Keys" => "Ripristina chiavi di cifratura",
"Delete Encryption Keys" => "Elimina chiavi di cifratura",
"Login Name" => "Nome utente",
"Create" => "Crea",
"Admin Recovery Password" => "Password di ripristino amministrativa",
"Enter the recovery password in order to recover the users files during password change" => "Digita la password di ripristino per recuperare i file degli utenti durante la modifica della password.",
"Search Users and Groups" => "Cerca utenti e gruppi",
"Add Group" => "Aggiungi gruppo",
"Group" => "Gruppo",
"Everyone" => "Chiunque",
"Admins" => "Amministratori",
"Default Quota" => "Quota predefinita",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Digita la quota di archiviazione (ad es.: \"512 MB\" or \"12 GB\")",
"Unlimited" => "Illimitata",
"Other" => "Altro",
"Username" => "Nome utente",
"Quota" => "Quote",
"Storage Location" => "Posizione di archiviazione",
"Last Login" => "Ultimo accesso",
"change full name" => "modica nome completo",
"set new password" => "imposta una nuova password",
"Default" => "Predefinito",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Se la tua installazione non si trova nella radice del dominio e utilizza il cron di sistema, potrebbero esserci problemi con la generazione degli URL. Per evitare questi problemi, imposta l'opzione \"overwritewebroot\"  nel file config.php al percorso della radice del sito della tua installazione (Suggerito: \"%s\")",
"URL generation in notification emails" => "Generazione di URL nelle email di notifica",
"Connectivity Checks" => "Controlli di connettività",
"No problems found" => "Nessun problema trovato",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
